/**
 * A simple Azure IoT example for sending telemetry.
 */

#include <WiFi.h>
#include "Esp32MQTTClient.h"
//
#include "az_iot/iothub_client/inc/iothub_client_options.h"
#include "az_iot/c-utility/inc/azure_c_shared_utility/shared_util_options.h"

// Please input the SSID and password of WiFi
const char* ssid     = "wifi";
const char* password = "pass";

/*String containing Hostname, Device Id & Device Key in the format:                         */
/*  "HostName=<host_name>;DeviceId=<device_id>;SharedAccessKey=<device_key>"                */
/*  "HostName=<host_name>;DeviceId=<device_id>;SharedAccessSignature=<device_sas_token>"    */

static const char* connectionString = "HostName=fengoo.azure-devices.net;DeviceId=mydevice;x509=true";

const char* x509privatekey = \
"-----BEGIN RSA PRIVATE KEY-----\n" \
"MIIJKAIBAAKCAgEAqspdo5Kc4cDuicJUSJJLjkFtdBbEJCu09W9EELCj9uSwicC+\n" \
"hidden content" \
"fhcn/Op4tGGkB3CYjSOKjaye811b2JD9pGqu0IOxuwcwBN3rzjkpETAid6g=\n" \
"-----END RSA PRIVATE KEY-----";


const char* x509certificate = \
"-----BEGIN CERTIFICATE-----\n" \
"MIIFsTCCA5mgAwIBAgIBAjANBgkqhkiG9w0BAQsFADA0MTIwMAYDVQQDDClBenVy\n" \
"hidden content" \
"ikenGUtj3ha2xpL6wjJI8GMWjDNR+dlFE4h3JCevhQUM3tjlh7GvdpGXXHFntv77\n" \
"JgAYvWlcz720yV/J+m83Xje871sM\n" \
"-----END CERTIFICATE-----\n" \
"-----BEGIN CERTIFICATE-----\n" \
"MIIFPDCCAySgAwIBAgIBATANBgkqhkiG9w0BAQsFADAqMSgwJgYDVQQDDB9BenVy\n" \
"hidden content" \
"kkDwA629x7WqiIx5nc8OHu1tTM8hYd1mLxZ2ZWS9wC/AF4RLZQ0PIoa3ZhWS7x2B\n" \
"-----END CERTIFICATE-----\n" \
"-----BEGIN CERTIFICATE-----\n" \
"MIIFRTCCAy2gAwIBAgIUMbyTc5kTluqGH4eAyCxKCiliOs4wDQYJKoZIhvcNAQEL\n" \
"hidden content" \
"F9wRL1WghaE0YGZM6rtSAD45DerOoCPDJWSUA1ag4770Lb/Aetl1OSVM8xw/MpHo\n" \
"DQci9opoMF8n\n" \
"-----END CERTIFICATE-----";


static bool hasIoTHub = false;

void setup() {
  Serial.begin(115200);
  Serial.println("Starting connecting WiFi.");
  delay(10);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("WiFi connected");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());

  // přidáno
  Esp32MQTTClient_SetOption(OPTION_TRUSTED_CERT, certificates);

  if ((Esp32MQTTClient_SetOption(OPTION_X509_CERT, x509certificate) != IOTHUB_CLIENT_OK) ||
          (Esp32MQTTClient_SetOption(OPTION_X509_PRIVATE_KEY, x509privatekey) != IOTHUB_CLIENT_OK)) {
      printf("failure to set options for x509, aborting\r\n");
      while(1){
        }
  } 

  
  if (!Esp32MQTTClient_Init((const uint8_t*)connectionString))
  {
    hasIoTHub = false;
    Serial.println("Initializing IoT hub failed.");
    return;
  }
  hasIoTHub = true;
}

void loop() {
  Serial.println("start sending events.");
  if (hasIoTHub)
  {
    char buff[128];

    // replace the following line with your data sent to Azure IoTHub
    snprintf(buff, 128, "{\"topic\":\"iot\"}");
    
    if (Esp32MQTTClient_SendEvent(buff))
    {
      Serial.println("Sending data succeed");
    }
    else
    {
      Serial.println("Failure...");
    }
    delay(5000);
  }
}
